flutter_custom_textfields library

Classes

AdvancedFileOutput
Accumulates logs in a buffer to reduce frequent disk, writes while optionally switching to a new log file if it reaches a certain size.
AdvancedOTPField
AdvancedOTPFieldState
AnsiColor
This class handles colorizing of terminal output.
CameraLocationPicker
ConsoleOutput
Default implementation of LogOutput.
CountryCode
CountryValidationRule
CustomLogFilter
CustomLogPrinter
CustomTextField
CustomTextFieldsErrorMessages
DateFormatter
Utility class for date formatting
DatePickerConfig
Configuration class for the Smart Date Picker
DatePickerController
Controller for managing date picker state and logic
DateTimeFormat
DevelopmentFilter
Prints all logs with level >= Logger.level while in development mode (eg when asserts are evaluated, Flutter calls this debug mode).
EmailTextField
EmailValidator
FileOutput
FileUtils
FlexiblePhoneField
FullNameTextField
FullnameValidator
HybridPrinter
A decorator for a LogPrinter that allows for the composition of different printers to handle different log messages. Provide it's constructor with a base printer, but include named parameters for any levels that have a different printer:
LogEvent
LogFilter
An abstract filter of log messages.
LogfmtPrinter
Outputs a logfmt message:
Logger
Use instances of logger to send log messages to the LogPrinter.
LoggerColors
LogOutput
Log output receives a OutputEvent from LogPrinter and sends it to the desired destination.
LogPrinter
An abstract handler of log events.
MemoryOutput
Buffers OutputEvents.
MultiOutput
Logs simultaneously to multiple LogOutput outputs.
OTPFieldDecoration
OTPFieldStyle
OTPModel
OTPValidator
OutputEvent
PasswordTextfield
PasswordValidator
PasswordValidatorLetters
PhoneValidationConfig
PhoneValidator
PinCodeModel
PinCodeTextfield
PinCodeValidator
PinOtpField
PrefixPrinter
A decorator for a LogPrinter that allows for the prepending of every line in the log output with a string for the level of that log. For example:
PrettyPrinter
Default implementation of LogPrinter.
ProductionFilter
Prints all logs with level >= Logger.level even in production.
SimplePrinter
Outputs simple log messages:
SmartDatePickerDialog
Dialog widget for date picker
SmartDatePickerField
Main date picker field widget
StreamOutput
TextArea
TextAreaValidator
UsernameInputFormatter
UsernameTextfield
UsernameValidator
ValidationResult

Enums

CameraMode
DateRestriction
Enum for date restriction types
DateSelectionMode
Level
Levels to control logging output. Logging can be enabled to include all levels above certain Level.
OTPAnimationType
OTPInputType
PhoneFieldStyle

Properties

customLevelColors Map<Level, AnsiColor>
final
customLevelEmojis Map<Level, String>
final

Functions

createLogger(Type type, {Level minLevel = Level.trace, bool enableDebugLogs = true}) Logger

Typedefs

DateTimeFormatter = String Function(DateTime time)
LocationImageCallback = void Function(File? image, double? lat, double? lng, String? address)
LogCallback = void Function(LogEvent event)
OutputCallback = void Function(OutputEvent event)